summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/widgets/tqwhatsthis.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'experimental/tqtinterface/qt4/src/widgets/tqwhatsthis.cpp')
-rw-r--r--experimental/tqtinterface/qt4/src/widgets/tqwhatsthis.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/experimental/tqtinterface/qt4/src/widgets/tqwhatsthis.cpp b/experimental/tqtinterface/qt4/src/widgets/tqwhatsthis.cpp
index 80e984c8c..3ada61988 100644
--- a/experimental/tqtinterface/qt4/src/widgets/tqwhatsthis.cpp
+++ b/experimental/tqtinterface/qt4/src/widgets/tqwhatsthis.cpp
@@ -311,7 +311,7 @@ void TQWhatsThat::hide()
void TQWhatsThat::mousePressEvent( TQMouseEvent* e )
{
pressed = TRUE;
- if ( e->button() == Qt::LeftButton && TQT_TQRECT_OBJECT(rect()).tqcontains( e->pos() ) ) {
+ if ( e->button() == Qt::LeftButton && TQT_TQRECT_OBJECT(rect()).contains( e->pos() ) ) {
#ifndef TQT_NO_RICHTEXT
if ( doc )
anchor = doc->anchorAt( e->pos() - TQPoint( hMargin, vMargin) );
@@ -326,14 +326,14 @@ void TQWhatsThat::mouseReleaseEvent( TQMouseEvent* e )
if ( !pressed )
return;
#ifndef TQT_NO_RICHTEXT
- if ( e->button() == Qt::LeftButton && doc && TQT_TQRECT_OBJECT(rect()).tqcontains( e->pos() ) ) {
+ if ( e->button() == Qt::LeftButton && doc && TQT_TQRECT_OBJECT(rect()).contains( e->pos() ) ) {
TQString a = doc->anchorAt( e->pos() - TQPoint( hMargin, vMargin ) );
TQString href;
if ( anchor == a )
href = a;
anchor = TQString::null;
if ( widget && wt && wt->dict ) {
- TQWhatsThisPrivate::WhatsThisItem * i = wt->dict->tqfind( widget );
+ TQWhatsThisPrivate::WhatsThisItem * i = wt->dict->find( widget );
if ( i && i->whatsthis && !i->whatsthis->clicked( href ) )
return;
}
@@ -545,7 +545,7 @@ bool TQWhatsThisPrivate::eventFilter( TQObject * o, TQEvent * e )
TQMouseEvent* me = (TQMouseEvent*) e;
TQPoint p = me->pos();
while( w && !i ) {
- i = dict->tqfind( w );
+ i = dict->find( w );
if ( !i ) {
p += w->pos();
w = w->parentWidget( TRUE );
@@ -670,7 +670,7 @@ void TQWhatsThisPrivate::say( TQWidget * widget, const TQString &text, const TQP
"automatic what's this? widget" );
// okay, now to tqfind a suitable location
int scr = ( widget ?
TQApplication::desktop()->screenNumber( widget ) :
@@ -735,13 +735,13 @@ void TQWhatsThisPrivate::say( TQWidget * widget, const TQString &text, const TQP
TQWhatsThisPrivate::WhatsThisItem* TQWhatsThisPrivate::newItem( TQWidget * widget )
{
- WhatsThisItem * i = dict->tqfind( (void *)widget );
+ WhatsThisItem * i = dict->find( (void *)widget );
if ( i )
TQWhatsThis::remove( widget );
i = new WhatsThisItem;
dict->insert( (void *)widget, i );
TQWidget * t = widget->tqtopLevelWidget();
- if ( !tlw->tqfind( (void *)t ) ) {
+ if ( !tlw->find( (void *)t ) ) {
tlw->insert( (void *)t, t );
t->installEventFilter( this );
}
@@ -764,7 +764,7 @@ void TQWhatsThisPrivate::add( TQWidget * widget, const TQString &text )
/*!
Adds \a text as "What's this" help for \a widget. If the text is
- rich text formatted (i.e. it tqcontains markup) it will be rendered
+ rich text formatted (i.e. it contains markup) it will be rendered
with the default stylesheet TQStyleSheet::defaultSheet().
The text is destroyed if the widget is later destroyed, so it need
@@ -790,7 +790,7 @@ void TQWhatsThis::add( TQWidget * widget, const TQString &text )
void TQWhatsThis::remove( TQWidget * widget )
{
TQWhatsThisPrivate::setUpWhatsThis();
- TQWhatsThisPrivate::WhatsThisItem * i = wt->dict->tqfind( (void *)widget );
+ TQWhatsThisPrivate::WhatsThisItem * i = wt->dict->find( (void *)widget );
if ( !i )
return;
@@ -804,7 +804,7 @@ void TQWhatsThis::remove( TQWidget * widget )
/*!
Returns the what's this text for widget \a w or TQString::null if
- there is no "What's this?" help for the widget. \a pos tqcontains
+ there is no "What's this?" help for the widget. \a pos contains
the mouse position; this is useful, for example, if you've
subclassed to make the text that is displayed position dependent.
@@ -819,7 +819,7 @@ TQString TQWhatsThis::textFor( TQWidget * w, const TQPoint& pos, bool includePar
TQWhatsThisPrivate::WhatsThisItem * i = 0;
TQPoint p = pos;
while( w && !i ) {
- i = wt->dict->tqfind( w );
+ i = wt->dict->find( w );
if ( !includeParents )
break;
if ( !i ) {
@@ -670,7 +670,7 @@ void TQWhatsThisPrivate::say( TQWidget * widget, const TQString &text, const TQP
"automatic what's this? widget" );
- // okay, now to tqfind a suitable location
+ // okay, now to find a suitable location
int scr = ( widget ?
TQApplication::desktop()->screenNumber( widget ) :